#
# spec file for package python-license-expression
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-license-expression
Version:        30.3.0
Release:        1.2
Summary:        Library to parse, compare, simplify and normalize license expressions
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/nexB/license-expression
Source:         https://files.pythonhosted.org/packages/source/l/license-expression/license-expression-%{version}.tar.gz
BuildRequires:  %{python_module boolean.py >= 4.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-boolean.py >= 4.0
BuildArch:      noarch
%python_subpackages

%description
This module defines a mini language to parse, validate, simplify, normalize and
compare license expressions using a boolean logic engine.

This supports SPDX license expressions and also accepts other license naming
conventions and license identifiers aliases to resolve and normalize licenses.

Using boolean logic, license expressions can be tested for equality,
containment, equivalence and can be normalized or simplified.

%prep
%setup -q -n license-expression-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests

%files %{python_files}
%license apache-2.0.LICENSE NOTICE
%doc README.rst
%{python_sitelib}/license[_-]expression*

%changelog
* Fri Mar 22 2024 Dirk Müller <dmueller@suse.com>
- update to 30.3.0:
  * Use latest skeleton
  * Update license list to latest ScanCode and SPDX 3.23
  * Drop support for Python 3.7
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 30.2.0:
  * Use latest skeleton
  * Update license list to latest ScanCode and SPDX 3.22
  * Add Python 3.12 support in CI
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 30.1.0
  * This is a minor release without API changes
  * Use latest skeleton (and updated configure script)
  * Update license list to latest ScanCode and SPDX 3.19
  * Use correct syntax for python_require
  * Drop using Travis and Appveyor
  * Drop support for Python 3.7 and add Python 3.11
* Thu Sep 22 2022 Matthias Fehring <buschmann23@opensuse.org>
- Requires boolean.py 4.0 or newer
* Sat Sep 17 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v30.0.0
  * Use latest skeleton (and updated configure script)
  * Drop using calver
  * Improve error checking when combining licenses
- from v21.6.14
  * Switch to calver for package versioning to better convey the
    currency of the bundled data.
  * Include https://scancode-licensedb.aboutcode.org/ licenses list
    with ScanCode (v21.6.7) and SPDX licenses (v3.13) keys. Add new
    functions to create Licensing using these licenses as LicenseSymbol.
  * Add new License.dedup() method to deduplicate and simplify license
    expressions without over simplifying.
  * Add new License.validate() method to return a new ExpressionInfo
    object with details on a license expression validation.
  * Drop support for Python 2.
  * Adopt the project skeleton from https://github.com/nexB/skeleton
    and its new configure script
* Wed Apr 15 2020 pgajdos@suse.com
- version update to 1.2
  * Fix anomalous backslashes in strings
  * Update the thirdparty directory structure.
  * New version of boolean.py library
  * Add ability to leave license expressions unsorted when simplifying
* Mon Sep  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Thu Sep  5 2019 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- New package, version 0.999
